Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Go ¶
func Go(fn func())
Go executes the provided function fn in a goroutine with safety features. It provides the following safety mechanisms:
`Panic recovery` to prevent application crashes
`Parameters`:
'fn': The function to be executed in the goroutine
Any panics during execution will be recovered and logged.
func GoContext ¶
GoContext executes the provided function fn in a goroutine with safety features. It provides the following safety mechanisms:
`Panic recovery` to prevent application crashes
`Context` checking for proper cancellation support
`Parameters`:
'ctx': Context for cancellation control
'fn': The function to be executed in the goroutine
The function will not execute if the context is already canceled. Any panics during execution will be recovered and logged.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.